(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue-clickaway')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue-clickaway'], factory) :
  (factory((global.VueBootstrapSelect = {}),global.vueClickaway));
}(this, (function (exports,vueClickaway) { 'use strict';

  //

  var script = {
    name: "VSelect",
    mixins: [vueClickaway.mixin],
    props: {
      labelEmpty: {
        type: String,
        default: "Nothing selected"
      },
      labelNotFound: {
        type: String,
        default: "No results found for"
      },
      options: {
        type: Array,
        default: function () { return []; }
      },
      search: {
        type: Boolean,
        default: false
      },
      showDefaultOption: {
        type: Boolean,
        default: false
      },
      textProp: {
        type: String,
        default: "text"
      },
      value: {
        type: [Object, String, Number],
        default: null
      },
      valueProp: {
        type: String,
        default: "value"
      }
    },
    data: function data() {
      return {
        show: false,
        selectedValue: this.value,
        searchValue: ""
      };
    },
    computed: {
      filteredProps: function filteredProps() {
        var this$1 = this;

        if (this.search && this.searchValue.length > 0) {
          return this.options.filter(function (item) {
            if (typeof option === "object") {
              return (
                item[this$1.textProp].toLowerCase().indexOf(this$1.searchValue) !== -1
              );
            } else {
              return item;
            }
          });
        }
        return this.options;
      }
    },
    methods: {
      handleSelect: function handleSelect(option) {
        this.selectedValue = option;
        this.hideDropdown();
        this.$emit("input", option);
      },
      hideDropdown: function hideDropdown() {
        this.show = false;
        this.searchValue = "";
      },
      getOptionLabel: function getOptionLabel(option) {
        if (typeof option === "object") {
          return option[this.textProp];
        }
        return option;
      }
    }
  };

  /* script */
              var __vue_script__ = script;
              
  /* template */
  var __vue_render__ = function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c(
      "div",
      {
        directives: [
          {
            name: "on-clickaway",
            rawName: "v-on-clickaway",
            value: _vm.hideDropdown,
            expression: "hideDropdown"
          }
        ],
        staticClass: "v-select"
      },
      [
        _c(
          "div",
          {
            staticClass: "v-select-toggle",
            on: {
              click: function($event) {
                _vm.show = !_vm.show;
              }
            }
          },
          [
            _c("div", [
              _vm._v(
                "\n            " +
                  _vm._s(
                    _vm.selectedValue
                      ? _vm.getOptionLabel(_vm.selectedValue)
                      : _vm.labelEmpty
                  ) +
                  "\n        "
              )
            ]),
            _vm._v(" "),
            _c("div", { staticClass: "arrow-down" })
          ]
        ),
        _vm._v(" "),
        _c(
          "div",
          {
            directives: [
              {
                name: "show",
                rawName: "v-show",
                value: _vm.show,
                expression: "show"
              }
            ],
            staticClass: "v-dropdown-container"
          },
          [
            _c(
              "ul",
              [
                _vm.search
                  ? _c("li", { staticClass: "search-container" }, [
                      _c("input", {
                        directives: [
                          {
                            name: "model",
                            rawName: "v-model",
                            value: _vm.searchValue,
                            expression: "searchValue"
                          }
                        ],
                        staticClass: "form-control",
                        attrs: {
                          placeholder: "Search",
                          type: "text",
                          autofocus: ""
                        },
                        domProps: { value: _vm.searchValue },
                        on: {
                          input: function($event) {
                            if ($event.target.composing) {
                              return
                            }
                            _vm.searchValue = $event.target.value;
                          }
                        }
                      })
                    ])
                  : _vm._e(),
                _vm._v(" "),
                _c(
                  "li",
                  {
                    directives: [
                      {
                        name: "show",
                        rawName: "v-show",
                        value: _vm.search && _vm.filteredProps.length === 0,
                        expression: "search && filteredProps.length === 0"
                      }
                    ],
                    staticClass: "v-dropdown-item"
                  },
                  [
                    _vm._v(
                      "\n                " +
                        _vm._s(_vm.labelNotFound) +
                        ': "' +
                        _vm._s(_vm.searchValue) +
                        '"\n            '
                    )
                  ]
                ),
                _vm._v(" "),
                _vm.showDefaultOption
                  ? _c(
                      "li",
                      { staticClass: "v-dropdown-item disabled default-option" },
                      [
                        _vm._v(
                          "\n                " +
                            _vm._s(_vm.labelEmpty) +
                            "\n            "
                        )
                      ]
                    )
                  : _vm._e(),
                _vm._v(" "),
                _vm._l(_vm.filteredProps, function(option, index) {
                  return _c(
                    "li",
                    {
                      key: "v-select-" + index,
                      staticClass: "v-dropdown-item",
                      class: {
                        selected:
                          _vm.selectedValue && option === _vm.selectedValue
                      },
                      on: {
                        click: function($event) {
                          return _vm.handleSelect(option)
                        }
                      }
                    },
                    [
                      _vm._v(
                        "\n                " +
                          _vm._s(_vm.getOptionLabel(option)) +
                          "\n            "
                      )
                    ]
                  )
                })
              ],
              2
            )
          ]
        )
      ]
    )
  };
  var __vue_staticRenderFns__ = [];
  __vue_render__._withStripped = true;

    /* style */
    var __vue_inject_styles__ = function (inject) {
      if (!inject) { return }
      inject("data-v-0875b3cc_0", { source: "\n.v-select[data-v-0875b3cc] {\n    position: relative;\n    width: 100%;\n    height: 30px;\n    background-color: #f8f9fa;\n    border-color: #f8f9fa;\n    border-radius: 0.25rem;\n    line-height: 1.5;\n    color: #212529;\n    font-size: 12px;\n    transition: background-color, border-color, box-shadow, .15s ease-in-out;\n    font-family: inherit, sans-serif;\n    cursor: pointer;\n}\n.v-select[data-v-0875b3cc]:hover {\n    background-color: #e2e6ea;\n    border-color: #dae0e5;\n}\n.v-select-toggle[data-v-0875b3cc] {\n    display: flex;\n    justify-content: space-between;\n    user-select: none;\n    padding: 0.375rem 0.75rem;\n}\n.arrow-down[data-v-0875b3cc] {\n    display: inline-block;\n    width: 0;\n    height: 0;\n    margin-left: 0.255em;\n    margin-top: 7px;\n    vertical-align: 0.255em;\n    content: \"\";\n    border-top: 0.3em solid;\n    border-right: 0.3em solid transparent;\n    border-bottom: 0;\n    border-left: 0.3em solid transparent;\n}\n.v-dropdown-container[data-v-0875b3cc] {\n    position: absolute;\n    width: 100%;\n    background: red;\n    padding: 0.5rem 0;\n    margin: 0.125rem 0 0;\n    color: #212529;\n    text-align: left;\n    list-style: none;\n    background-color: #fff;\n    background-clip: padding-box;\n    border-radius: 0.25rem;\n    border: 1px solid rgba(0,0,0,.15);\n    z-index: 1000;\n}\nul[data-v-0875b3cc] {\n    font-size: 12px;\n    color: #424242;\n    text-align: left;\n    list-style: none;\n    background-color: #fff;\n    background-clip: padding-box;\n    padding: 0px;\n    margin: 0px;\n}\n.v-dropdown-item[data-v-0875b3cc] {\n    line-height: 25px;\n    padding: 0.5rem 1.25rem;\n    user-select: none;\n}\n.v-dropdown-item[data-v-0875b3cc]:hover:not(.default-option) {\n    text-decoration: none;\n    background-color: #f8f9fa;\n}\n.v-dropdown-item.disabled[data-v-0875b3cc] {\n    color: #9A9B9B;\n}\n.v-dropdown-item.selected[data-v-0875b3cc] {\n    background-color: #007bff;\n    color: #fff;\n}\n.v-dropdown-item.selected[data-v-0875b3cc]:hover {\n    background-color: #007bff;\n    color: #fff;\n}\n.search-container[data-v-0875b3cc] {\n    padding: 0.5rem 1.25rem;\n}\ninput[data-v-0875b3cc] {\n    width: 100%;\n}\n", map: {"version":3,"sources":["/Users/luissandoval/Documents/Me/Github/vue-bootstrap-select/src/vue-bootstrap-select.vue"],"names":[],"mappings":";AAqIA;IACA,mBAAA;IACA,YAAA;IACA,aAAA;IACA,0BAAA;IACA,sBAAA;IACA,uBAAA;IACA,iBAAA;IACA,eAAA;IACA,gBAAA;IACA,yEAAA;IACA,iCAAA;IACA,gBAAA;CACA;AAEA;IACA,0BAAA;IACA,sBAAA;CACA;AAEA;IACA,cAAA;IACA,+BAAA;IACA,kBAAA;IACA,0BAAA;CACA;AAGA;IACA,sBAAA;IACA,SAAA;IACA,UAAA;IACA,qBAAA;IACA,gBAAA;IACA,wBAAA;IACA,YAAA;IACA,wBAAA;IACA,sCAAA;IACA,iBAAA;IACA,qCAAA;CACA;AAEA;IACA,mBAAA;IACA,YAAA;IACA,gBAAA;IACA,kBAAA;IACA,qBAAA;IACA,eAAA;IACA,iBAAA;IACA,iBAAA;IACA,uBAAA;IACA,6BAAA;IACA,uBAAA;IACA,kCAAA;IACA,cAAA;CACA;AAEA;IACA,gBAAA;IACA,eAAA;IACA,iBAAA;IACA,iBAAA;IACA,uBAAA;IACA,6BAAA;IACA,aAAA;IACA,YAAA;CACA;AAEA;IACA,kBAAA;IACA,wBAAA;IACA,kBAAA;CACA;AAEA;IACA,sBAAA;IACA,0BAAA;CACA;AAEA;IACA,eAAA;CACA;AAEA;IACA,0BAAA;IACA,YAAA;CACA;AAEA;IACA,0BAAA;IACA,YAAA;CACA;AAEA;IACA,wBAAA;CACA;AAEA;IACA,YAAA;CACA","file":"vue-bootstrap-select.vue","sourcesContent":["<template>\n    <div\n        v-on-clickaway=\"hideDropdown\"\n        class=\"v-select\">\n        <div\n            @click=\"show = !show\"\n            class=\"v-select-toggle\">\n            <div>\n                {{ selectedValue ? getOptionLabel(selectedValue) : labelEmpty }}\n            </div>\n            <div class=\"arrow-down\"></div>\n        </div>\n        <div\n            v-show=\"show\"\n            class=\"v-dropdown-container\">\n            <ul>\n                <li\n                    v-if=\"search\"\n                    class=\"search-container\">\n                    <input\n                        placeholder=\"Search\"\n                        class=\"form-control\"\n                        type=\"text\"\n                        v-model=\"searchValue\"\n                        autofocus>\n                </li>\n                <li\n                    v-show=\"search && filteredProps.length === 0\"\n                    class=\"v-dropdown-item\">\n                    {{ labelNotFound }}: \"{{ searchValue }}\"\n                </li>\n                <li\n                    v-if=\"showDefaultOption\"\n                    class=\"v-dropdown-item disabled default-option\">\n                    {{ labelEmpty }}\n                </li>\n                <li\n                    v-for=\"(option, index) in filteredProps\"\n                    :key=\"`v-select-${index}`\"\n                    class=\"v-dropdown-item\"\n                    :class=\"{'selected' : selectedValue && option === selectedValue}\"\n                    @click=\"handleSelect(option)\">\n                    {{ getOptionLabel(option) }}\n                </li>\n            </ul>\n        </div>\n    </div>\n</template>\n\n<script>\nimport { mixin as clickaway } from \"vue-clickaway\";\n\nexport default {\n  name: \"VSelect\",\n  mixins: [clickaway],\n  props: {\n    labelEmpty: {\n      type: String,\n      default: \"Nothing selected\"\n    },\n    labelNotFound: {\n      type: String,\n      default: \"No results found for\"\n    },\n    options: {\n      type: Array,\n      default: () => []\n    },\n    search: {\n      type: Boolean,\n      default: false\n    },\n    showDefaultOption: {\n      type: Boolean,\n      default: false\n    },\n    textProp: {\n      type: String,\n      default: \"text\"\n    },\n    value: {\n      type: [Object, String, Number],\n      default: null\n    },\n    valueProp: {\n      type: String,\n      default: \"value\"\n    }\n  },\n  data() {\n    return {\n      show: false,\n      selectedValue: this.value,\n      searchValue: \"\"\n    };\n  },\n  computed: {\n    filteredProps() {\n      if (this.search && this.searchValue.length > 0) {\n        return this.options.filter(item => {\n          if (typeof option === \"object\") {\n            return (\n              item[this.textProp].toLowerCase().indexOf(this.searchValue) !== -1\n            );\n          } else {\n            return item;\n          }\n        });\n      }\n      return this.options;\n    }\n  },\n  methods: {\n    handleSelect(option) {\n      this.selectedValue = option;\n      this.hideDropdown();\n      this.$emit(\"input\", option);\n    },\n    hideDropdown() {\n      this.show = false;\n      this.searchValue = \"\";\n    },\n    getOptionLabel(option) {\n      if (typeof option === \"object\") {\n        return option[this.textProp];\n      }\n      return option;\n    }\n  }\n};\n</script>\n\n<style lang=\"css\" scoped>\n.v-select {\n    position: relative;\n    width: 100%;\n    height: 30px;\n    background-color: #f8f9fa;\n    border-color: #f8f9fa;\n    border-radius: 0.25rem;\n    line-height: 1.5;\n    color: #212529;\n    font-size: 12px;\n    transition: background-color, border-color, box-shadow, .15s ease-in-out;\n    font-family: inherit, sans-serif;\n    cursor: pointer;\n}\n\n.v-select:hover {\n    background-color: #e2e6ea;\n    border-color: #dae0e5;\n}\n\n.v-select-toggle {\n    display: flex;\n    justify-content: space-between;\n    user-select: none;\n    padding: 0.375rem 0.75rem;\n}\n\n\n.arrow-down {\n    display: inline-block;\n    width: 0;\n    height: 0;\n    margin-left: 0.255em;\n    margin-top: 7px;\n    vertical-align: 0.255em;\n    content: \"\";\n    border-top: 0.3em solid;\n    border-right: 0.3em solid transparent;\n    border-bottom: 0;\n    border-left: 0.3em solid transparent;\n}\n\n.v-dropdown-container {\n    position: absolute;\n    width: 100%;\n    background: red;\n    padding: 0.5rem 0;\n    margin: 0.125rem 0 0;\n    color: #212529;\n    text-align: left;\n    list-style: none;\n    background-color: #fff;\n    background-clip: padding-box;\n    border-radius: 0.25rem;\n    border: 1px solid rgba(0,0,0,.15);\n    z-index: 1000;\n}\n\nul {\n    font-size: 12px;\n    color: #424242;\n    text-align: left;\n    list-style: none;\n    background-color: #fff;\n    background-clip: padding-box;\n    padding: 0px;\n    margin: 0px;\n}\n\n.v-dropdown-item {\n    line-height: 25px;\n    padding: 0.5rem 1.25rem;\n    user-select: none;\n}\n\n.v-dropdown-item:hover:not(.default-option) {\n    text-decoration: none;\n    background-color: #f8f9fa;\n}\n\n.v-dropdown-item.disabled {\n    color: #9A9B9B;\n}\n\n.v-dropdown-item.selected {\n    background-color: #007bff;\n    color: #fff;\n}\n\n.v-dropdown-item.selected:hover {\n    background-color: #007bff;\n    color: #fff;\n}\n\n.search-container {\n    padding: 0.5rem 1.25rem;\n}\n\ninput {\n    width: 100%;\n}\n</style>\n"]}, media: undefined });

    };
    /* scoped */
    var __vue_scope_id__ = "data-v-0875b3cc";
    /* module identifier */
    var __vue_module_identifier__ = undefined;
    /* functional template */
    var __vue_is_functional_template__ = false;
    /* component normalizer */
    function __vue_normalize__(
      template, style, script$$1,
      scope, functional, moduleIdentifier,
      createInjector, createInjectorSSR
    ) {
      var component = (typeof script$$1 === 'function' ? script$$1.options : script$$1) || {};

      // For security concerns, we use only base name in production mode.
      component.__file = "/Users/luissandoval/Documents/Me/Github/vue-bootstrap-select/src/vue-bootstrap-select.vue";

      if (!component.render) {
        component.render = template.render;
        component.staticRenderFns = template.staticRenderFns;
        component._compiled = true;

        if (functional) { component.functional = true; }
      }

      component._scopeId = scope;

      {
        var hook;
        if (style) {
          hook = function(context) {
            style.call(this, createInjector(context));
          };
        }

        if (hook !== undefined) {
          if (component.functional) {
            // register for functional component in vue file
            var originalRender = component.render;
            component.render = function renderWithStyleInjection(h, context) {
              hook.call(context);
              return originalRender(h, context)
            };
          } else {
            // inject component registration as beforeCreate hook
            var existing = component.beforeCreate;
            component.beforeCreate = existing ? [].concat(existing, hook) : [hook];
          }
        }
      }

      return component
    }
    /* style inject */
    function __vue_create_injector__() {
      var head = document.head || document.getElementsByTagName('head')[0];
      var styles = __vue_create_injector__.styles || (__vue_create_injector__.styles = {});
      var isOldIE =
        typeof navigator !== 'undefined' &&
        /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());

      return function addStyle(id, css) {
        if (document.querySelector('style[data-vue-ssr-id~="' + id + '"]')) { return } // SSR styles are present.

        var group = isOldIE ? css.media || 'default' : id;
        var style = styles[group] || (styles[group] = { ids: [], parts: [], element: undefined });

        if (!style.ids.includes(id)) {
          var code = css.source;
          var index = style.ids.length;

          style.ids.push(id);

          if (isOldIE) {
            style.element = style.element || document.querySelector('style[data-group=' + group + ']');
          }

          if (!style.element) {
            var el = style.element = document.createElement('style');
            el.type = 'text/css';

            if (css.media) { el.setAttribute('media', css.media); }
            if (isOldIE) {
              el.setAttribute('data-group', group);
              el.setAttribute('data-next-index', '0');
            }

            head.appendChild(el);
          }

          if (isOldIE) {
            index = parseInt(style.element.getAttribute('data-next-index'));
            style.element.setAttribute('data-next-index', index + 1);
          }

          if (style.element.styleSheet) {
            style.parts.push(code);
            style.element.styleSheet.cssText = style.parts
              .filter(Boolean)
              .join('\n');
          } else {
            var textNode = document.createTextNode(code);
            var nodes = style.element.childNodes;
            if (nodes[index]) { style.element.removeChild(nodes[index]); }
            if (nodes.length) { style.element.insertBefore(textNode, nodes[index]); }
            else { style.element.appendChild(textNode); }
          }
        }
      }
    }
    /* style inject SSR */
    

    
    var component = __vue_normalize__(
      { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
      __vue_inject_styles__,
      __vue_script__,
      __vue_scope_id__,
      __vue_is_functional_template__,
      __vue_module_identifier__,
      __vue_create_injector__,
      undefined
    );

  // Import vue component

  // install function executed by Vue.use()
  function install(Vue) {
    if (install.installed) { return; }
    install.installed = true;
    Vue.component('VueBootstrapSelect', component);
  }

  // Create module definition for Vue.use()
  var plugin = {
    install: install,
  };

  // To auto-install when vue is found
  /* global window global */
  var GlobalVue = null;
  if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
  } else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
  }
  if (GlobalVue) {
    GlobalVue.use(plugin);
  }

  // It's possible to expose named exports when writing components that can
  // also be used as directives, etc. - eg. import { RollupDemoDirective } from 'rollup-demo';
  // export const RollupDemoDirective = component;

  exports.default = component;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
